$(document).ready(function () {
  "use strict";

  $('.php-email-form').on('submit', function (event) {
    event.preventDefault();

    var $thisForm = $(this);

    // Reset any error or success messages
    $thisForm.find('.loading').addClass('d-block');
    $thisForm.find('.error-message, .sent-message').removeClass('d-block');

    // Collect form data and prepare it to send
    var name = $thisForm.find('input[name="name"]').val().trim();
    var email = $thisForm.find('input[name="email"]').val().trim();
    var phone = $thisForm.find('input[name="phone"]').val().trim();
    var location = $thisForm.find('input[name="location"]').val().trim();
    var message = $thisForm.find('textarea[name="message"]').val().trim();
    var businessType = parseInt($thisForm.find('select[name="businessType"]').val());
    var otherBusiness = $thisForm.find('input[name="otherBusiness"]').val().trim();
    var surveillanceType = parseInt($thisForm.find('select[name="surveillanceType"]').val());
    var existingCameras = $thisForm.find('select[name="existingCameras"]').val();

    // Validate the required fields
    if (name === "" || email === "" || message === "" || phone === "" || location === "") {
      displayError($thisForm, "Name, email, message, phone and location are required fields.");
      return;
    }

    // Optional: Further validation like email format
    var emailPattern = /^[a-zA-Z0-9._-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,6}$/;
    if (!emailPattern.test(email)) {
      displayError($thisForm, "Please enter a valid email address.");
      return;
    }

    // Prepare the form data object
    var formData = {
      name: name,
      email: email,
      phone: phone,
      location: location,
      message: message,
      businessType: businessType,
      otherBusiness: otherBusiness,
      surveillanceType: surveillanceType,
      existingCameras: existingCameras,
      createdTime: new Date().toISOString()
    };
    // console.log(formData)

    // Send data via AJAX
    $.ajax({
      method: "POST",
      url: "http://usstaging.ivisecurity.com:8004/FormSubmissionMail_1_0",
      data: JSON.stringify(formData),  // Send data as JSON
      contentType: "application/json",  // Set content type to JSON
      success: function(response) {
        console.log(response)
        if (response.statusCode === 200) {
          $thisForm.find('.sent-message').text(response.message).addClass('d-block');
          $thisForm.find('.loading').removeClass('d-block');
          $thisForm.trigger("reset");
        } else {
          displayError($thisForm, response.message);
        }
      },
      error: function(xhr, status, error) {
        displayError($thisForm, "Something went wrong. Please try again.");
      }
    });
  });

  function displayError($thisForm, error) {
    $thisForm.find('.loading').removeClass('d-block');
    $thisForm.find('.error-message').text(error).addClass('d-block');
  }

});
